;; -*- emacs-lisp -*-
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; $Id: gnus.el,v 1.12 2006-11-06 21:02:42 rscholz Exp $
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; Gnus-Einstellungen von Raymond Scholz (fr Gnus 5.10 und hher)
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; Diese Gnus-Konfiguration ist innerhalb der letzten 6 Jahre von ein
;; paar kmmerlichen Zeilen zu einer ziemlich komplexen Konfiguration
;; gewachsen, die insbesondere viele nicht mit Gnus mitgelieferte
;; Pakete bercksichtigt.
;;
;; Basierend auf stundenlanger Lektre der Info-Seiten, Lesen der
;; Newsgroups gnu.emacs.help, gnu.emacs.sources, gnu.emacs.gnus, und
;; der Inspiration vieler Menschen (besonderer Dank hier an Dischi,
;; Crunchy, Hans-Jrgen von der Uni Bremen, Kai Gnusjohann^WGrojohann
;; und ShengHuo ZHU) ist dieses Sammelsurium entstanden.
;;
;; Ich nutze Emacs 21.3.50 (aktuelle CVS-Version) und die
;; Entwicklerversion von Gnus, genannt Oort (demnchst No Gnus).
;; D.h. einige Einstellungen werden nur mit dieser neueren Version von
;; Gnus funktionieren.  Ich habe mich bemht, an diesen Stellen einen
;; Vermerk zu machen.
;;
;; Diese Gnus-Konfiguration ist modular, d.h. die Einstellungen sind
;; nach Funktionen oder Paketen gegliedert in einzelnen, handlichen
;; Dateien abgelegt.
;;
;; Wenn Du gerade die HTML-Version dieser Einstellungen betrachtest,
;; kannst Du mit dem Browser unten die Einstellungen der einzelnen
;; Pakete anklicken.
;;
;; Wenn Du gerade in Emacs eine dieser Dateien betrachtest, findest Du
;; an vielen Stellen einen Verweis der Form:
;;
;;  (Info-goto-node "(Gnus)Terminology")
;;
;; Gehe mit dem Cursor hinter die schlieende Klammer und drcke `C-x
;; C-e' - und schon wird die zu der aktuellen Einstellung passende
;; Info-Seite angezeigt.
;;
;; Die offizielle Quelle dieser Dateien ist
;;   <http://www.zonix.de/projects/emacs/config>
;;
;;
;;                                                     Ray, 11.05.03
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

;; hier liegen alle meine Emacs- und Gnus-Einstellungen
(defvar zonix-elisp-dir "~/el/")

;; Datei laden, wenn vorhanden, sonst Warnung
(defun zonix-load-part (part)
  (let ((fullname (concat zonix-elisp-dir part)))
    (if (file-exists-p fullname)
	(load fullname)
      (message (format "Loading %s (source)...failed" fullname)))))

;; ShengHuo ZHU empfiehlt in <2nwuxp7xla.fsf@zsh.cs.rochester.edu>
;; beim Einsatz von Entwicklerversionen wie Oort Gnus/No Gnus die
;; folgende Zeile:
(require 'gnus-load)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Einstellungen, die grtenteils benutzerspezifisch sind
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(zonix-load-part "gnus_groupparams.el")    ; Einstellungen fr Gruppen
(zonix-load-part "gnus_splitting.el")      ; autom. Sortierung von Mails
(zonix-load-part "gnus_styles.el")         ; Einstellungen beim Posten
(zonix-load-part "gnus_archive.el")        ; Archivierung
(zonix-load-part "gnus_sources.el")        ; Quellen fr Mail & News

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Einstellungen, die das Verhalten und Aussehen von Gnus bestimmen
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(zonix-load-part "gnus_internals.el")      ; Innereien von Gnus
(zonix-load-part "gnus_group.el")          ; Group-Buffer
(zonix-load-part "gnus_summary.el")        ; Summary-Buffer
(zonix-load-part "gnus_article.el")        ; Article-Buffer
(zonix-load-part "gnus_message.el")        ; Message-Buffer
(zonix-load-part "gnus_score.el")          ; Scoring

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Zusatzpakete, teilweise in Gnus enthalten
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;

(zonix-load-part "gnus_gpg.el")            ; GPG/PGP/SMIME mit Gnus
(zonix-load-part "gnus_mailcrypt.el")      ; PGP/GPG mit MailCrypt
(zonix-load-part "gnus_bbdb.el")           ; Addressbuch
(zonix-load-part "gnus_boxquote.el")       ; Box-Quoting
(zonix-load-part "gnus_delay.el")          ; verzgertes Senden von Artikeln
(zonix-load-part "gnus_dired.el")          ; dired-Erweiterung fr Gnus
(zonix-load-part "gnus_dumbquotes.el")     ; UTF-8-Dumbquotes
;(zonix-load-part "gnus_epop3.el")          ; POP3
;(zonix-load-part "gnus_filterhist.el")    ; Filter
(zonix-load-part "gnus_footnote.el")       ; Funoten
(zonix-load-part "gnus_html.el")           ; was tun mit HTML-Mails?
(zonix-load-part "gnus_ispell.el")         ; Rechtschreibkontrolle
(zonix-load-part "gnus_mdrtn.el")          ; Paket fr Moderatoren
;(zonix-load-part "gnus_junk.el")          ; Spam-Mails
(zonix-load-part "gnus_ldap.el")           ; LDAP
(zonix-load-part "gnus_msgutils.el")       ; Message-Mode-Utilities
(zonix-load-part "gnus_ngn.el")            ; Gruppen-Namen einsetzen
;(zonix-load-part "gnus_nnir.el")           ; Suchen
(zonix-load-part "gnus_outlook.el")        ; kaputte Postings reparieren
(zonix-load-part "gnus_randomsig.el")      ; Zufallssignatur
;(zonix-load-part "gnus_tc.el")            ; besseres Zitieren
(zonix-load-part "gnus_vcard.el")          ; vCards interpretieren
(zonix-load-part "gnus_web.el")            ; WWW-Quellen fr Gnus

(zonix-load-part "gnus_testing.el")        ; noch zu testende Einstellungen

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Format-Specs kompilieren         (Info-goto-node "(Gnus)Compilation")
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(gnus-compile)

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Cancel-Lock-Passwort                                   (ab Gnus 5.10)
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(load-file "~/.canlock.el")  ;; chmod 400 ~/.canlock.el
